<?php
if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

function get_ajax_params() {
  $nonce = check_ajax_referer( 'vmv_preloader_token', 'vmv_token', false );
  header( 'Content-Type: application/json' );

  if ( ! $nonce ) {
    $response = [
      'success' => false,
      'error'   => 'Security violation!'
    ];
    echo json_encode( $response );
    die;
  }

  $option = vmv_preloader_get_option_front();

  $response = [
    'success' => true,
    'options' => $option
  ];
  echo json_encode( $response );
  die;
}

function set_ajax_params() {
  $nonce = check_ajax_referer( 'vmv_preloader_token', 'vmv_token', false );
  header( 'Content-Type: application/json' );

  if ( ! $nonce ) {
    $response = [
      'success' => false,
      'error'   => 'Security violation!'
    ];
    echo json_encode( $response );
    die;
  }

  $option     = vmv_preloader_get_option();
  $new_option = array();

  $arrayItemsBoolean = array(
    "pluginActivated",
    "delete_option_on_deactivate",
    "viewEachLoad",
    "isPremium",
    "vmvBgIsActive",
    "pluginOptionsLogoText",
    "pluginOptionsFillColorSecond",
  );

  foreach ( $_POST as $key => $value ) {
    if ( in_array( $key, $arrayItemsBoolean ) ) {
      $new_option[ $key ] = filter_var( sanitize_text_field( $value ), FILTER_VALIDATE_BOOLEAN );
    } else {
      $new_option[ $key ] = sanitize_text_field( $value );
    }
  }

  if ( $option['themeFile'] !== $new_option['themeFile'] ) {
    if ( $new_option['isPremium'] === true ) {
      $path_preloader_sources = 'premium-animations/';
    } else {
      $path_preloader_sources = 'base-animations/';
    }

    $f_json      = VMV_ONE__PLUGIN_DIR . $path_preloader_sources . $new_option['themeFile'];
    $jsonDecoded = json_decode( file_get_contents( $f_json ), true );

    $new_option['SVGWidth']                     = $jsonDecoded['SVGWidth'];
    $new_option['SVGHeight']                    = $jsonDecoded['SVGHeight'];
    $new_option['uniqCorrectSpeedDraw']         = $jsonDecoded['uniqCorrectSpeedDraw'];
    $new_option['pluginOptionsLogoText']        = filter_var( sanitize_text_field( $jsonDecoded['pluginOptionsLogoText'] ), FILTER_VALIDATE_BOOLEAN );
    $new_option['pluginOptionsFillColorSecond'] = filter_var( sanitize_text_field( $jsonDecoded['pluginOptionsFillColorSecond'] ), FILTER_VALIDATE_BOOLEAN );
    $new_option['pulseLeft']                    = $jsonDecoded['pulseLeft'];
    $new_option['pulseBottom']                  = $jsonDecoded['pulseBottom'];
    $new_option['pulseWidth']                   = $jsonDecoded['pulseWidth'];
    $new_option['pulseIsCustom']                = $jsonDecoded['pulseIsCustom'];
    $new_option['customPulseStyle']             = base64_decode( $jsonDecoded['customPulseStyle'] );
    $new_option['customPulseHtml']              = base64_decode( $jsonDecoded['customPulseHtml'] );
    $new_option['customPulseScript']            = base64_decode( $jsonDecoded['customPulseScript'] );
    $new_option['pulseCustomElement']           = $jsonDecoded['pulseCustomElement'];

    if ( $new_option['isPremium'] === true ) {
      $new_option['premiumDataSVG'] = base64_decode( $jsonDecoded['SVG'] );
    }
  }

  $update_option = 0;
  foreach ( $new_option as $key => $value ) {
    if ( $value !== $option[ $key ] ) {
      $update_option = 1;
    }
  }

  if ( $update_option == 1 ) {
    $update_option = vmv_preloader_update_option( $new_option, $option );
  }

  $response = [
    'success' => $update_option == 1,
    'options' => $update_option == 1 ? vmv_preloader_get_option_front() : null
  ];

  echo json_encode( $response );
  die;
}


function vmv_list_base_animations() {
  $nonce = check_ajax_referer( 'vmv_preloader_token', 'vmv_token', false );
  header( 'Content-Type: application/json' );
  if ( ! $nonce ) {
    $response = [
      'success' => false,
      'error'   => 'Security violation!'
    ];
    echo json_encode( $response );
    die;
  }

  $listNameFiles = array();
  $file_paths    = list_files( VMV_ONE__PLUGIN_DIR . "base-animations", 1 );
  foreach ( $file_paths as $index => $item ) {
    if ( ! empty( wp_basename( $item ) ) && isset( pathinfo( wp_basename( $item ) )['extension'] ) ) {
      array_push( $listNameFiles, wp_basename( $item ) );
    }
  }

  $response = [
    'success' => true,
    'data'    => [
      'list_files' => $listNameFiles,
    ]
  ];
  echo json_encode( $response );
  die;
}

function vmv_upload_file_premium_animations() {
  $nonce = check_ajax_referer( 'vmv_preloader_token', 'vmv_token', false );
  header( 'Content-Type: application/json' );

  if ( ! $nonce ) {
    $response = [
      'success' => false,
      'error'   => 'Security violation!'
    ];
    echo json_encode( $response );
    die;
  }

  $path_folder_save = VMV_ONE__PLUGIN_DIR . VMV_ONE__UPLOAD_DIR;

  if ( ! file_exists( $path_folder_save ) ) {
    mkdir( $path_folder_save, 0777, true );
  }

  if ( $_FILES['file']['tmp_name'] != '' ) {
    $new_file_path = $path_folder_save . '/' . $_FILES['file']['name'];
    move_uploaded_file( $_FILES['file']['tmp_name'], $new_file_path );
  }

  $response['response'] = "SUCCESS";

  echo json_encode( $response );
  die;
}

function vmv_delete_file_premium_animations() {
  $nonce = check_ajax_referer( 'vmv_preloader_token', 'vmv_token', false );
  header( 'Content-Type: application/json' );

  if ( ! $nonce ) {
    $response = [
      'success' => false,
      'error'   => 'Security violation!'
    ];
    echo json_encode( $response );
    die;
  }

  $file = VMV_ONE__PLUGIN_DIR . VMV_ONE__UPLOAD_DIR . '/' . sanitize_text_field( $_POST['filename_to_delete'] );

  if ( file_exists( $file ) ) {
    wp_delete_file( $file );
    $response['success'] = true;
  } else {
    $response['success'] = false;
    $response['file']    = $file;
    $response['error']   = 'File not found!';
  }
  echo json_encode( $response );
  die;
}

function vmv_list_premium_animations() {
  $nonce = check_ajax_referer( 'vmv_preloader_token', 'vmv_token', false );
  header( 'Content-Type: application/json' );
  if ( ! $nonce ) {
    $response = [
      'success' => false,
      'error'   => 'Security violation!'
    ];
    echo json_encode( $response );
    die;
  }

  $listNameFiles = array();

  $file_paths = list_files( VMV_ONE__PLUGIN_DIR . VMV_ONE__UPLOAD_DIR, 1 );
  foreach ( $file_paths as $index => $item ) {
    if ( ! empty( wp_basename( $item ) ) && isset( pathinfo( wp_basename( $item ) )['extension'] ) ) {
//      array_push( $listNameFiles, wp_basename( $item ) );
      $listNameFiles[] = wp_basename( $item );
    }
  }

  $response = [
    'success' => true,
    'data'    => [
      'list_files' => $listNameFiles,
    ]
  ];
  echo json_encode( $response );
  die;
}
