<?php
if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

require_once( __DIR__ . '/../CrawlerDetect/init.php' );

use Jaybizzle\CrawlerDetect\CrawlerDetect;

// Admin panel VUE app init sources
function vmv_admin_frontend() {
  if ( ( is_admin() ) && ( array_key_exists( 'page', $_GET ) ) && $_GET['page'] == VMV_ONE__ADMIN_PAGE ) {
    wp_register_script( 'vmv_preloader_frontend_appjs', VMV_ONE__PLUGIN_URL . VMV_ONE__BASE . 'front-end-vue3/dist/assets/index.js', array(), VMV_ONE__PLUGIN_VERSION, false );
    wp_register_script( 'vmv_preloader_frontend_vendors', VMV_ONE__PLUGIN_URL . VMV_ONE__BASE . 'front-end-vue3/dist/assets/vendor.js', array(), VMV_ONE__PLUGIN_VERSION, false );
    wp_register_style( 'vmv_preloader_css', VMV_ONE__PLUGIN_URL . VMV_ONE__BASE . 'front-end-vue3/dist/assets/index.css', array(), VMV_ONE__PLUGIN_VERSION, 'screen' );
    wp_enqueue_script( 'vmv_preloader_frontend_appjs' );
    wp_enqueue_script( 'vmv_preloader_frontend_vendors' );
    wp_enqueue_style( 'vmv_preloader_css' );
  }
}

function set_scripts_type_attribute( $tag, $handle, $src ) {
  if ( 'vmv_preloader_frontend_appjs' === $handle ) {
    $tag = '<script type="module" crossorigin src="' . $src . '"></script>';
  }
  if ( 'vmv_preloader_frontend_vendors' === $handle ) {
    $tag = '<link rel="modulepreload" href="' . $src . '">';
  }

  return $tag;
}

add_filter( 'script_loader_tag', 'set_scripts_type_attribute', 10, 3 );

function vmv_admin_plugin_links( $links, $file ) {
  $plugin_file = explode( VMV_ONE__PLUGIN_DIR_NAME . '/', VMV_ONE__PLUGIN_FILE );
  $plugin_file = VMV_ONE__PLUGIN_DIR_NAME . '/' . $plugin_file[1];
  if ( $file == $plugin_file ) {
    $settings = '<a href="' . VMV_ONE__PLUGIN_ADMIN_URL . '">Settings</a>';
    array_unshift( $links, $settings );
  }

  return $links;
}

// End Admin panel VUE app init sources

function put_main_code_to_template() {
  $option = vmv_preloader_get_option();

  $strategy = esc_html( stripslashes( $option['strategyHide'] ) );
  $logoText = esc_html( stripslashes( $option['logoText'] ) );

  $fill1  = esc_html( stripslashes( $option['fill1'] ) );
  $fill2  = esc_html( stripslashes( $option['fill2'] ) );
  $fill3  = esc_html( stripslashes( $option['fill3'] ) );
  $shadow = esc_html( stripslashes( $option['shadow'] ) );

  $bgBody            = esc_html( stripslashes( $option['bgBody'] ) );
  $bgStop1           = esc_html( stripslashes( $option['bgStop1'] ) );
  $bgStop2           = esc_html( stripslashes( $option['bgStop2'] ) );
  $gradientType      = esc_html( stripslashes( $option['gradientType'] ) );
  $gradientDirection = esc_html( stripslashes( $option['gradientDirection'] ) );

  $vmvBgIsActive = esc_html( stripslashes( $option['vmvBgIsActive'] ) );
  $vmvBgData     = esc_html( stripslashes( $option['vmvBgData'] ) );

  $w1 = esc_html( stripslashes( $option['w1'] ) );
  $w2 = esc_html( stripslashes( $option['w2'] ) );
  $w3 = esc_html( stripslashes( $option['w3'] ) );
  $w4 = esc_html( stripslashes( $option['w4'] ) );

  $timeDelay  = esc_html( stripslashes( $option['timeDelay'] ) );
  $speedRatio = esc_html( stripslashes( $option['speedRatio'] ) );

  $logoTextPrevious = esc_html( stripslashes( $option['logoTextPrevious'] ) );
  $dataLetters      = $option['dataLetters'];

  $themeFile          = esc_html( stripslashes( $option['themeFile'] ) );
  $themeFileIsPremium = $option['isPremium'];

  $SVGWidth  = $option['SVGWidth'] ;
  $SVGHeight = $option['SVGHeight'] ;

  $pulseLeft          = $option['pulseLeft'] ;
  $pulseBottom        =  $option['pulseBottom'] ;
  $pulseWidth         = $option['pulseWidth'] ;
  $pulseCustomElement =  $option['pulseCustomElement'];

  $uniqCorrectSpeedDraw = $option['uniqCorrectSpeedDraw'];

  if ( $themeFile == 'SignatureFont.json' ) {

    if ( $logoTextPrevious !== $logoText ) {
      $path_preloader_sources = 'base-animations/';
      $f_json                 = VMV_ONE__PLUGIN_DIR . $path_preloader_sources . $themeFile;
      $jsonDecoded            = json_decode( file_get_contents( $f_json ), true );
      $logoLetters            = str_split( $logoText );
      $arrayGlyphs            = [];
      foreach ( $logoLetters as $itemLetter ) {
        $itemExist = in_array( 'G__' . ord( $itemLetter ), array_column( $arrayGlyphs, 'id' ) );
        if ( $itemExist === false ) {
          $itemIndex     = array_search( 'G__' . ord( $itemLetter ), array_column( $jsonDecoded['glyphs'], 'id' ) );
          $arrayGlyphs[] = $jsonDecoded['glyphs'][ $itemIndex ];
        }
      }
      $jsonGlyphs                     = json_encode( $arrayGlyphs );
      $new_option                     = array();
      $new_option['logoTextPrevious'] = $logoText;
      $new_option['dataLetters']      = $jsonGlyphs;
      vmv_preloader_update_option( $new_option, $option );
      $dataLettersToTemplate = $jsonGlyphs;
    } else {
      $dataLettersToTemplate = $dataLetters;
    }
    echo <<<END
    <div id="_vmv_" data-w1="$w1" data-w2="$w2" data-w3="$w3" data-w4="$w4" data-timedelay="$timeDelay" data-speedratio="$speedRatio" data-gradienttype="$gradientType" data-strategy="$strategy"><div class="_vmv_pr__b"><div class="_vmv_pr__b-in"><div class="_vmv_pr__b-in-in"><svg class="_vmv_pr__svg" xmlns="http://www.w3.org/2000/svg"><defs class="_vmv_pr__svg-defs"></defs><g fill-rule="evenodd" fill="none" class="_vmv_pr__svg-glyphs"></g></svg><div class="_vmv_pr__ind"><div class="_vmv_pr__ind-in _vmv_pr__ind-in--pr-1"></div><div class="_vmv_pr__ind-in _vmv_pr__ind-in--pr-2"></div></div></div></div></div></div>
    <script data-vmv-j1>
    (function(u,l,p){var n;(n=p.define)&&n.amd?n([],function(){return l}):(n=p.modules)?n[u.toLowerCase()]=l:"object"===typeof exports?module.exports=l:p[u]=l})("Fat",function(){function u(a,c,b,d,e,f,v,g,m,h,l,r){this.i=a;this.B=a.j;this.style=c;this.G=c.replace(/([A-Z])/g,"-$1").toLowerCase();this.o=d;this.s=e;this.c=d;this.H=f;this.m=v;this.duration=g;this.h=m;this.ease=n(m)?[]:null;this.time=0;this.g=h;this.f=l;this.F=b;this.a=r;this.D="px"!==f}function l(){this.id=y++;this.stack=[];this.u=p.bind(this);this.exec=this.b=0}function p(a){var c=this.stack,b=c.length;if(b){this.exec=requestAnimationFrame(this.u);this.b||(this.b=a);var d=!1;if(b)for(var e=0;e<b;e++){var f=c[e];f&&(d=!0,f.C(this,a)||(c[e]=null))}this.b=a;d||this.destroy()}}function n(a){return"string"===typeof a}function x(a){return"undefined"===typeof a}var w=Math.max(screen.width,screen.height),C=w*(window.devicePixelRatio||1),t=parseFloat,y=0,h=u.prototype;h.animate=function(a,c){var b=this.o,d=this.s,e=this.duration, f=this.i,v=b===d||!1;a=this.time+=a-(c||a);c=a>=e;if(!v)if(c)var g=d;else{var m;if(m=this.ease)g=m.length?(d-b)*m[w/e*a+.5>>0]/C:(d-b)*a/e;else if(m=this.h)g=1===m.length?m(a/e):m(a,b,d,e);g=b+g;g=this.D?(g*w+.5>>0)/w:g+.5>>0}b=this.style;v||this.c===g||(this.c=g,g+=this.H,"custom"!==b&&(f.nodeType?this.A(g):f[b]=g));this.f&&this.f.call(f,c?1:a/e,g);c&&(this.time=-1,this.g&&this.g.call(f))};h.C=function(a,c){if(-1===this.time)this.i[this.F]=null;else{var b=c-a.b;if(this.a)if("view"===this.a)if(b= this.i.getBoundingClientRect(),0<=b.top&&b.bottom<=window.innerHeight)this.a=0;else return!0;else{if(0<(this.a-=b))return!0;this.a=0}this.animate(c,a.b);return!0}};h.A=function(a){var c=this.B,b=this.G;this.m?c.setProperty(b,a,"important"):c.setProperty(b,a)};h.v=function(a,c,b,d,e,f,v,g){x(a)?a=this.c:a=t(a);n(c)&&(c=t(c));this.o=a;this.s=c;this.duration=d;this.time=0;this.m=b;this.h!==e&&(this.ease=n(e)?[]:null,this.h=e);this.g=f;this.f=v;this.a=g};h=l.prototype;h.w=function(a,c,b,d,e,f,v,g,m,h, l,r){if("custom"===c)d=d||0;else if(a.nodeType){var q=a.j||(a.j=a.style);d=(x(d)?q[c]:d)||(a.l||(a.l=getComputedStyle(a)))[c]}else d=x(d)?a[c]:d;q=""+d;"auto"===q&&(q="0");d=t(q);if(n(e)){var k=e;e=t(e);f||(f=k.substring((""+e).length))}f||(f=q.substring((""+d).length));c=new u(a,c,b,d,e,f,v,g,m,h,l,r,!1,!1,!1);this.stack[this.stack.length]=c;a[b]=c};h.animate=function(a,c,b,d){b?"function"===typeof b&&(d=b,b={}):b={};n(a)?a=document.querySelectorAll(a):a.constructor===Array||(a=[a]);var e=b.delay, f=b.duration||400,h=b.ease||"",g=Object.keys(c),m=g.length;d=d||b.callback||!1;var l=b.step,u=b.force;b=b.init;for(var r=0;r<m;r++){var q=g[r],k=c[q],p=void 0,w=void 0;k.constructor===Array?(p=k[0],w=k[2],k=k[1]):"object"===typeof k&&(e=k.delay||e,f=k.duration||f,h=k.ease||h,p=k.from,w=k.unit,k=k.to);for(var t=r===m-1,x="_fat_"+q+this.id,z=0,y=a.length;z<y;z++){var A=a[z];b&&0===r&&(A.l=null);var B=!b&&A[x];B?B.v(p,k,u,f,h,t&&d,t&&l,e):this.w(A,q,x,p,k,w,u,f,h,t&&d,t&&l,e)}}this.exec||(this.exec= requestAnimationFrame(this.u));return this};h.destroy=function(){this.exec&&(this.exec=0,this.stack=[],this.b=0);return this};h.create=function(a){return new l(a)};return new l}(),this);
    </script>
    <style data-vmv-s1> #_vmv_{--vmv-bg-body:$bgBody;--vmv-bg-stop1:$bgStop1;--vmv-bg-stop2:$bgStop2;--vmv-bg-direction:$gradientDirection;--vmv-fill:$fill1;--vmv-fill2:$fill2;--vmv-fill3:$fill3;--vmv-shadow:$shadow;--vmv-pulse-bottom:$pulseBottom;--vmv-pulse-width:$pulseWidth}#_vmv_{position:fixed;top:0;left:0;height:100vh;width:100vw;background-color:var(--vmv-bg-body);z-index:2147483637;background-blend-mode:screen;line-height:1;font-size:1px;overflow:hidden;transform:translateZ(2147483638em)}#_vmv_.is-hidding{transition:all .5s;opacity:0}._vmv_pr__b{opacity:1;display:flex;height:100%;width:100%;justify-content:center;align-items:center;position:relative}._vmv_pr__b-in{position:relative}._vmv_pr__b--r-bg{background:radial-gradient(var(--vmv-bg-direction),var(--vmv-bg-stop1),var(--vmv-bg-stop2))}._vmv_pr__b--l-bg{background:linear-gradient(var(--vmv-bg-direction),var(--vmv-bg-stop1),var(--vmv-bg-stop2))}._vmv_pr__svg{max-width:none;overflow:visible;filter:drop-shadow(1px 1px 3px var(--vmv-shadow));transform:translateZ(2111221em)}  ._vmv_pr__svg-glyphs{stroke:var(--vmv-fill) !important}._vmv_pr__svg{position:relative}._vmv_pr__ind{opacity:0;transition:opacity .2s;position:absolute;bottom:calc(var(--vmv-pulse-bottom)*var(--vmv_scale)*1px);left:100%;width:calc(var(--vmv-pulse-width)*var(--vmv_scale)*1px);height:calc(var(--vmv-pulse-width)*var(--vmv_scale)*1px)}._vmv_pr__ind-in{width:0;position:absolute;border-radius:50%;border:1px solid var(--vmv-fill3);top:50%;left:50%;transform:translateX(-50%) translateY(-50%)}._vmv_pr__ind-in._vmv_pr__ind-in--pr-1{animation:pulse 1.5s ease infinite 0s}._vmv_pr__ind-in._vmv_pr__ind-in--pr-2{animation:pulse 1.5s ease infinite .4s}._vmv_pr__ind-in:before{content:'';display:block;padding-top:100%}@keyframes pulse{0%{width:0;opacity:0}30%{opacity:1}100%{width:100%;opacity:0}}.vmv-fill{opacity:0;stroke:var(--vmv-fill) !important}</style>
    END;

    if ( $vmvBgIsActive && $vmvBgData ) {
      echo <<<END
      <style data-vmv-s2> ._vmv_pr__b:before{content:'';position:absolute;top:50%;left:50%;width:120%;height:120%;transform:translateY(-50%) translateX(-50%);background-image:url('$vmvBgData');filter:blur(20px);background-position:50% 50%;background-size:cover;background-color:var(--vmv-bg-body)} </style>
      END;
    }

    echo <<<END
    <script data-vmv-j2>const _VMV_dataGlyphs=$dataLettersToTemplate,_VMV_logo="$logoText",_VMV_fontSpaceScale=.06,_VMV_baseHeight=$SVGHeight,_VMV_pulseWidth=$pulseWidth,_VMV_uniqCorrectSpeedDraw=1;(()=>{const t=document.getElementById("_vmv_"),e=1e3*t.dataset.timedelay||0,i=t.dataset.strategy,s=t.dataset.w1||80,o=t.dataset.w2||0,d=t.dataset.w3||0,a=t.dataset.w4||0,n=t.dataset.speedratio||5;let _,r=0,l=!1,h=!1;const c=1*n;if(void 0===window._vmv_hidden||window._vmv_hidden&&t)return t.remove(),M(),!1;"fullLoad"===i&&(console.log("pageIsLoaded"),_=setTimeout((()=>{h=!0,x()}),e),window.onload=function(){x&&(clearTimeout(_),h=!0,x())});const m=t.querySelector("._vmv_pr__svg"),w=t.querySelector("._vmv_pr__svg-defs"),v=t.querySelector("._vmv_pr__svg-glyphs"),u=t.querySelector("._vmv_pr__b");_VMV_dataGlyphs.forEach((t=>{t.defs.forEach((t=>{w.innerHTML+=t}))}));const p=_VMV_logo.split(""),g=_VMV_dataGlyphs.map((function(t){return t.id}));p.forEach((t=>{const e=t.charCodeAt(0),i=g.indexOf("G__"+e);-1!==i&&(v.innerHTML+=_VMV_dataGlyphs[i].glyph)}));const y=m.querySelectorAll("._vmv_pr__svg-glyphs > g");let f=0;y.forEach((t=>{const e=t.getAttribute("data-space-end"),i=t.getAttribute("data-space-start");f+=.06*i,t.style.transform="translateX("+f+"px)",f+=1*t.dataset.width+.06*e,r+=1*t.dataset.width+.06*i+.06*e})),m.setAttribute("viewBox","0 0 "+r+" "+_VMV_baseHeight);let b=r;const V=document.getElementById("_vmv_fade");function x(){l&&!h&&(t.querySelector("._vmv_pr__ind").style.opacity=1),l&&h&&(setTimeout((()=>{t.classList.add("is-hidding")}),500),setTimeout((()=>{t.remove(),M(),function(){if(window._vmv_demo)return!1;(function(){const t=Object.assign({},localStorage);for(let e in t)e.includes(window._vmv_prefix)&&localStorage.removeItem(e);document.cookie.split(";").forEach((t=>{t.includes(window._vmv_prefix)&&(document.cookie=t+"; max-age=-1;")}))})(),console.log(window._vmv_storage),window._vmv_storage.setItem(window._vmv_prefix+"_"+window._vmv_stamp,"done"),window._vmv_session_storage||(document.cookie=window._vmv_prefix+"_"+window._vmv_stamp+"=done; max-age=31104000; path=/")}()}),1e3))}function M(){[...document.querySelectorAll("script, style")].forEach((t=>{const e=t?.dataset;if(e)for(const[i]of Object.entries(e))(i.includes("vmvJ")||i.includes("vmvS"))&&t.remove()}))}setTimeout((()=>{V.style.opacity=0,t.style.display="block";const e="radial"===t.dataset.gradienttype?"_vmv_pr__b--r-bg":"_vmv_pr__b--l-bg";u.classList.add(e)}),200),setTimeout((()=>{window._vmv_s0.remove(),V.remove(),function(){L();const t=Fat.create();let s=0,o=1;const d=[...document.querySelectorAll("._vmv_pr__svg-glyphs path")],a=d.length,n=[],_=[];d.forEach(((d,r)=>{d.classList.add("vmv-fill");const m=d.parentElement;o=m.hasAttribute("data-duration")?m.dataset.duration:1;const w=d.getTotalLength(),v=c*w/o;n[r]=v,_[r]=s,s+=v,t.animate(d,{custom:1},{duration:n[r],delay:_[r],step:function(t,e){this.style.opacity=1,this.style.strokeDasharray=w,this.style.strokeDashoffset=w-w*e},callback:function(){a===r+1&&function(){l=!0,"end"===i&&e>=1e3?setTimeout((()=>{h=!0,x()}),e):"end"===i&&e<1e3&&(h=!0);x()}()}})}))}()}),500),setTimeout((()=>{u.style.width="101%"}));const S=new class{constructor(t,e,i,s){this.mobile=window.matchMedia("(max-width:767px)"),this.tablet=window.matchMedia("(min-width:768px) and (max-width: 1023px)"),this.desktop=window.matchMedia("(min-width:1024px) and (max-width: 1399px)"),this.wide_desktop=window.matchMedia("(min-width:1400px)"),this.w1_width=null,this.w2_width=null,this.w3_width=null,this.w4_width=null,this.initWidth(t,e,i,s)}initWidth(t,e,i,s){this.w1_width=0===Number(t)?.8:Number(t)/100,this.w2_width=0===Number(e)?this.w1_width:Number(e)/100,this.w3_width=0===Number(i)?this.w2_width:Number(i)/100,this.w4_width=0===Number(s)?this.w3_width:Number(s)/100}getWidthCorrection(){return this.mobile.matches?this.w1_width:this.tablet.matches?this.w2_width:this.desktop.matches?this.w3_width:this.wide_desktop.matches?this.w4_width:void 0}}(s,o,d,a);let T=0;function L(){t.style.paddingLeft="1px",T=t.getBoundingClientRect().width,t.style.paddingLeft="0px";const e=T*S.getWidthCorrection()/(b+2.2*_VMV_pulseWidth);t.style.setProperty("--vmv_scale",e),m.style.width=b*e+"px",m.style.height=_VMV_baseHeight*e+"px"}window.addEventListener("resize",L)})();</script>
    END;

  } else if ( $themeFileIsPremium ) {

    $pulseIsCustom       = $option['pulseIsCustom'];
    $premiumDataSVG      = $option['premiumDataSVG'];
    $customPulseStyle    = $option['customPulseStyle'];
    $defaultPulseElement = ( $pulseIsCustom ? '' : '<div class="_vmv_pr__ind"> <div class="_vmv_pr__ind-in _vmv_pr__ind-in--pr-1"></div> <div class="_vmv_pr__ind-in _vmv_pr__ind-in--pr-2"></div> </div>' );
    $pulseCSS            = ( $pulseIsCustom ? $customPulseStyle : "._vmv_pr__ind{opacity:0;transition:opacity .2s;position:absolute;bottom:0;left:100%;margin-left:calc(var(--vmv-pulse-left)*var(--vmv_scale));margin-bottom:calc(var(--vmv-pulse-bottom)*var(--vmv_scale));width:calc(var(--vmv-pulse-width)*var(--vmv_scale)*1px);height:calc(var(--vmv-pulse-width)*var(--vmv_scale)*1px);transform-origin:0 100%}._vmv_pr__ind.vmv-pulse-run{opacity:1}._vmv_pr__ind-in{width:0;position:absolute;border-radius:50%;border:1px solid var(--vmv-fill3);top:50%;left:50%;transform:translateX(-50%) translateY(-50%)}._vmv_pr__ind.vmv-pulse-run ._vmv_pr__ind-in._vmv_pr__ind-in--pr-1{animation:pulse 1.5s ease infinite 0s}._vmv_pr__ind.vmv-pulse-run ._vmv_pr__ind-in._vmv_pr__ind-in--pr-2{animation:pulse 1.5s ease infinite .4s}._vmv_pr__ind-in:before{content:'';display:block;padding-top:100%}@keyframes pulse{0%{width:0;opacity:0}30%{opacity:1}100%{width:100%;opacity:0}}" );
    $pulseElement        = ( $pulseIsCustom ? $pulseCustomElement : '._vmv_pr__ind' );

    echo <<<END
      <div id="_vmv_" data-w1="$w1" data-w2="$w2" data-w3="$w3" data-w4="$w4" data-timedelay="$timeDelay" data-speedratio="$speedRatio" data-gradienttype="$gradientType" data-strategy="$strategy"><div class="_vmv_pr__b"><div class="_vmv_pr__b-in"><div class="_vmv_pr__b-in-in"><svg class="_vmv_pr__svg" xmlns="http://www.w3.org/2000/svg"><g fill-rule="evenodd" fill="none" class="_vmv_pr__svg-glyphs">$premiumDataSVG</g></svg>$defaultPulseElement</div></div></div></div>
      <script data-vmv-j1>
      (function(u,l,p){var n;(n=p.define)&&n.amd?n([],function(){return l}):(n=p.modules)?n[u.toLowerCase()]=l:"object"===typeof exports?module.exports=l:p[u]=l})("Fat",function(){function u(a,c,b,d,e,f,v,g,m,h,l,r){this.i=a;this.B=a.j;this.style=c;this.G=c.replace(/([A-Z])/g,"-$1").toLowerCase();this.o=d;this.s=e;this.c=d;this.H=f;this.m=v;this.duration=g;this.h=m;this.ease=n(m)?[]:null;this.time=0;this.g=h;this.f=l;this.F=b;this.a=r;this.D="px"!==f}function l(){this.id=y++;this.stack=[];this.u=p.bind(this);this.exec=this.b=0}function p(a){var c=this.stack,b=c.length;if(b){this.exec=requestAnimationFrame(this.u);this.b||(this.b=a);var d=!1;if(b)for(var e=0;e<b;e++){var f=c[e];f&&(d=!0,f.C(this,a)||(c[e]=null))}this.b=a;d||this.destroy()}}function n(a){return"string"===typeof a}function x(a){return"undefined"===typeof a}var w=Math.max(screen.width,screen.height),C=w*(window.devicePixelRatio||1),t=parseFloat,y=0,h=u.prototype;h.animate=function(a,c){var b=this.o,d=this.s,e=this.duration, f=this.i,v=b===d||!1;a=this.time+=a-(c||a);c=a>=e;if(!v)if(c)var g=d;else{var m;if(m=this.ease)g=m.length?(d-b)*m[w/e*a+.5>>0]/C:(d-b)*a/e;else if(m=this.h)g=1===m.length?m(a/e):m(a,b,d,e);g=b+g;g=this.D?(g*w+.5>>0)/w:g+.5>>0}b=this.style;v||this.c===g||(this.c=g,g+=this.H,"custom"!==b&&(f.nodeType?this.A(g):f[b]=g));this.f&&this.f.call(f,c?1:a/e,g);c&&(this.time=-1,this.g&&this.g.call(f))};h.C=function(a,c){if(-1===this.time)this.i[this.F]=null;else{var b=c-a.b;if(this.a)if("view"===this.a)if(b= this.i.getBoundingClientRect(),0<=b.top&&b.bottom<=window.innerHeight)this.a=0;else return!0;else{if(0<(this.a-=b))return!0;this.a=0}this.animate(c,a.b);return!0}};h.A=function(a){var c=this.B,b=this.G;this.m?c.setProperty(b,a,"important"):c.setProperty(b,a)};h.v=function(a,c,b,d,e,f,v,g){x(a)?a=this.c:a=t(a);n(c)&&(c=t(c));this.o=a;this.s=c;this.duration=d;this.time=0;this.m=b;this.h!==e&&(this.ease=n(e)?[]:null,this.h=e);this.g=f;this.f=v;this.a=g};h=l.prototype;h.w=function(a,c,b,d,e,f,v,g,m,h, l,r){if("custom"===c)d=d||0;else if(a.nodeType){var q=a.j||(a.j=a.style);d=(x(d)?q[c]:d)||(a.l||(a.l=getComputedStyle(a)))[c]}else d=x(d)?a[c]:d;q=""+d;"auto"===q&&(q="0");d=t(q);if(n(e)){var k=e;e=t(e);f||(f=k.substring((""+e).length))}f||(f=q.substring((""+d).length));c=new u(a,c,b,d,e,f,v,g,m,h,l,r,!1,!1,!1);this.stack[this.stack.length]=c;a[b]=c};h.animate=function(a,c,b,d){b?"function"===typeof b&&(d=b,b={}):b={};n(a)?a=document.querySelectorAll(a):a.constructor===Array||(a=[a]);var e=b.delay, f=b.duration||400,h=b.ease||"",g=Object.keys(c),m=g.length;d=d||b.callback||!1;var l=b.step,u=b.force;b=b.init;for(var r=0;r<m;r++){var q=g[r],k=c[q],p=void 0,w=void 0;k.constructor===Array?(p=k[0],w=k[2],k=k[1]):"object"===typeof k&&(e=k.delay||e,f=k.duration||f,h=k.ease||h,p=k.from,w=k.unit,k=k.to);for(var t=r===m-1,x="_fat_"+q+this.id,z=0,y=a.length;z<y;z++){var A=a[z];b&&0===r&&(A.l=null);var B=!b&&A[x];B?B.v(p,k,u,f,h,t&&d,t&&l,e):this.w(A,q,x,p,k,w,u,f,h,t&&d,t&&l,e)}}this.exec||(this.exec= requestAnimationFrame(this.u));return this};h.destroy=function(){this.exec&&(this.exec=0,this.stack=[],this.b=0);return this};h.create=function(a){return new l(a)};return new l}(),this);
      </script>
      <style data-vmv-s1>#_vmv_{--vmv-bg-body:$bgBody;--vmv-bg-stop1:$bgStop1;--vmv-bg-stop2:$bgStop2;--vmv-bg-direction:$gradientDirection;--vmv-fill:$fill1;--vmv-fill2:$fill2;--vmv-fill3:$fill3;--vmv-shadow:$shadow;--vmv-pulse-bottom:$pulseBottom;--vmv-pulse-left:$pulseLeft;--vmv-pulse-width:$pulseWidth}#_vmv_{position:fixed;top:0;left:0;height:100vh;width:100vw;background-color:var(--vmv-bg-body);z-index:2147483637;background-blend-mode:screen;line-height:1;font-size:1px;overflow:hidden;transform:translateZ(2147483638em)}#_vmv_.is-hidding{transition:all .5s;opacity:0}._vmv_pr__b{opacity:1;display:flex;height:100%;width:100%;justify-content:center;align-items:center;position:relative}._vmv_pr__b-in{position:relative}._vmv_pr__b--r-bg{background:radial-gradient(var(--vmv-bg-direction),var(--vmv-bg-stop1),var(--vmv-bg-stop2))}._vmv_pr__b--l-bg{background:linear-gradient(var(--vmv-bg-direction),var(--vmv-bg-stop1),var(--vmv-bg-stop2))}._vmv_pr__svg{max-width:none;overflow:visible;filter:drop-shadow(1px 1px 3px var(--vmv-shadow));transform:translateZ(2111221em)}._vmv_pr__svg-glyphs{stroke:var(--vmv-fill) !important}._vmv_pr__svg{position:relative}$pulseCSS .vmv-fill{opacity:0;stroke:var(--vmv-fill);stroke-linecap:round}.vmv-fill-line1 .vmv-fill{stroke:var(--vmv-fill) !important}.vmv-fill-line2 .vmv-fill{stroke:var(--vmv-fill2) !important}.vmv-fill-line3 .vmv-fill{stroke:var(--vmv-fill3) !important}</style>
    END;

    if ( $vmvBgIsActive && $vmvBgData ) {
      echo <<<END
        <style data-vmv-s2>._vmv_pr__b:before{content:'';position:absolute;top:50%;left:50%;width:120%;height:120%;transform:translateY(-50%) translateX(-50%);background-image:url('$vmvBgData');filter:blur(20px);background-position:50% 50%;background-size:cover;background-color:var(--vmv-bg-body)}</style>
      END;
    }

    echo <<<END
      <script data-vmv-j2>const _VMV_baseWidth=$SVGWidth,_VMV_baseHeight=$SVGHeight,_VMV_pulseWidth=$pulseWidth,_VMV_pulseElement="$pulseElement",_VMV_uniqCorrectSpeedDraw=$uniqCorrectSpeedDraw;(()=>{const t=document.getElementById("_vmv_"),e=1e3*t.dataset.timedelay||0,i=t.dataset.strategy,s=t.dataset.w1||80,d=t.dataset.w2||0,o=t.dataset.w3||0,n=t.dataset.w4||0,a=t.dataset.speedratio||5;let _,h=!1,l=!1;const w=a*_VMV_uniqCorrectSpeedDraw;if(void 0===window._vmv_hidden||window._vmv_hidden&&t)return t.remove(),v(),!1;"fullLoad"===i&&(console.log("pageIsLoaded"),_=setTimeout((()=>{l=!0,u()}),e),window.onload=function(){u&&(clearTimeout(_),l=!0,u())});const r=t.querySelector("._vmv_pr__svg"),m=t.querySelector("._vmv_pr__b");r.setAttribute("viewBox","0 0 "+_VMV_baseWidth+" "+_VMV_baseHeight);const c=document.getElementById("_vmv_fade");function u(){h&&!l&&t.querySelector("$pulseElement").classList.add("vmv-pulse-run"),h&&l&&(setTimeout((()=>{t.classList.add("is-hidding")}),500),setTimeout((()=>{t.remove(),v(),function(){if(window._vmv_demo)return!1;(function(){const t=Object.assign({},localStorage);for(let e in t)e.includes(window._vmv_prefix)&&localStorage.removeItem(e);document.cookie.split(";").forEach((t=>{t.includes(window._vmv_prefix)&&(document.cookie=t+"; max-age=-1;")}))})(),console.log(window._vmv_storage),window._vmv_storage.setItem(window._vmv_prefix+"_"+window._vmv_stamp,"done"),window._vmv_session_storage||(document.cookie=window._vmv_prefix+"_"+window._vmv_stamp+"=done; max-age=31104000; path=/")}()}),1e3))}function v(){[...document.querySelectorAll("script, style")].forEach((t=>{const e=t?.dataset;if(e)for(const[i]of Object.entries(e))(i.includes("vmvJ")||i.includes("vmvS"))&&t.remove()}))}setTimeout((()=>{c.style.opacity=0,t.style.display="block";const e="radial"===t.dataset.gradienttype?"_vmv_pr__b--r-bg":"_vmv_pr__b--l-bg";m.classList.add(e)}),200),setTimeout((()=>{window._vmv_s0.remove(),c.remove(),function(){f();const t=Fat.create();let s=0,d=1;const o=[...document.querySelectorAll(".vmv-fill")],n=o.length,a=[],_=[];o.forEach(((o,r)=>{o.classList.add("vmv-fill");const m=o.parentElement;d=m.hasAttribute("data-duration")?m.dataset.duration:1;const c=o.getTotalLength(),v=w*c/d;a[r]=v,_[r]=s,s+=v,t.animate(o,{custom:1},{duration:a[r],delay:_[r],step:function(t,e){this.style.opacity=1,this.style.strokeDasharray=c,this.style.strokeDashoffset=c-c*e},callback:function(){n===r+1&&function(){h=!0,"end"===i&&e>=1e3?setTimeout((()=>{l=!0,u()}),e):"end"===i&&e<1e3&&(l=!0);u()}()}})}))}()}),500),setTimeout((()=>{m.style.width="101%"}));const p=new class{constructor(t,e,i,s){this.mobile=window.matchMedia("(max-width:767px)"),this.tablet=window.matchMedia("(min-width:768px) and (max-width: 1023px)"),this.desktop=window.matchMedia("(min-width:1024px) and (max-width: 1399px)"),this.wide_desktop=window.matchMedia("(min-width:1400px)"),this.w1_width=null,this.w2_width=null,this.w3_width=null,this.w4_width=null,this.initWidth(t,e,i,s)}initWidth(t,e,i,s){this.w1_width=0===Number(t)?.8:Number(t)/100,this.w2_width=0===Number(e)?this.w1_width:Number(e)/100,this.w3_width=0===Number(i)?this.w2_width:Number(i)/100,this.w4_width=0===Number(s)?this.w3_width:Number(s)/100}getWidthCorrection(){return this.mobile.matches?this.w1_width:this.tablet.matches?this.w2_width:this.desktop.matches?this.w3_width:this.wide_desktop.matches?this.w4_width:void 0}}(s,d,o,n);let g=0;function f(){t.style.paddingLeft="1px",g=t.getBoundingClientRect().width,t.style.paddingLeft="0px";const e=g*p.getWidthCorrection()/(_VMV_baseWidth+2.2*_VMV_pulseWidth);t.style.setProperty("--vmv_scale",e),r.style.width=_VMV_baseWidth*e+"px",r.style.height=_VMV_baseHeight*e+"px"}window.addEventListener("resize",f)})();</script>
    END;
  }
}

function put_base_code_to_template( $demoViewArg ) {
  $option       = vmv_preloader_get_option();
  $bgBody       = esc_html( stripslashes( $option['bgBody'] ) );
  $timeStamp    = esc_html( stripslashes( $option['timeStamp'] ) );
  $viewEachLoad = esc_html( stripslashes( $option['viewEachLoad'] ) );

  $demoView = 'false';
  if ( $demoViewArg ) {
    $demoView = 'true';
  }

  echo <<<END
  <style data-vmv-s0 data-stamp="$timeStamp" data-demo="$demoView" data-storagesession="$viewEachLoad"> body,html,#_vmv_,#_vmv_fade{background-color:$bgBody !important}#_vmv_fade{transition:opacity .3s;z-index:2147483638}#_vmv_{display:none}#_vmv_,#_vmv_fade{position:fixed;top:0;left:0;height:100vh;width:100vw;transform:translateZ(2147483638em)}</style>
  <script data-vmv-j0>window._vmv_s0=document.querySelector("style[data-vmv-s0]"),window._vmv_prefix="vmv_PredL",window._vmv_stamp=_vmv_s0.dataset.stamp,window._vmv_storage="true"===_vmv_s0.dataset.storagesession?sessionStorage:localStorage,window._vmv_demo="true"===_vmv_s0.dataset.demo,window._vmv_session_storage="true"===_vmv_s0.dataset.storagesession,window._vmv_hidden=!!_vmv_storage.getItem(_vmv_prefix+"_"+_vmv_stamp),_vmv_demo&&(window._vmv_hidden=!1),_vmv_hidden||document.querySelector(":root").insertAdjacentHTML("afterbegin",'<div id="_vmv_fade"></div>');</script>
  END;
}

// Init demo template  
function vmv_add_custom_demo_template( $template ) {
  $option = vmv_preloader_get_option();
  $pageId = $option['previewIdPage'];

  global $post;
  if ( $post->post_type == 'page' && $post->ID == $pageId ) {
    return VMV_ONE__PLUGIN_DIR . 'preview-template/vmv-preloader-preview.php';
  }

  return $template;
}

add_filter( 'page_template', 'vmv_add_custom_demo_template' );

function vmv_preloader_head_section() {
  $CrawlerDetect   = new CrawlerDetect;
  $isNotCrawler    = ! $CrawlerDetect->isCrawler();
  $option          = vmv_preloader_get_option();
  $pluginActivated = $option['pluginActivated'];
  $timeStamp       = esc_html( stripslashes( $option['timeStamp'] ) );
  $currentCookie   = 'vmv_PredL_' . $timeStamp;
  $pageId          = $option['previewIdPage'];

  global $post;
  $demoView = $post->ID == $pageId;

  if ( ( ( ! isset( $_COOKIE[ $currentCookie ] ) && $pluginActivated && $isNotCrawler ) || $demoView ) ) {
    put_base_code_to_template( $demoView );
  }
}

function vmv_preloader_footer_section() {
  $CrawlerDetect   = new CrawlerDetect;
  $isNotCrawler    = ! $CrawlerDetect->isCrawler();
  $option          = vmv_preloader_get_option();
  $pluginActivated = $option['pluginActivated'];
  $timeStamp       = esc_html( stripslashes( $option['timeStamp'] ) );
  $currentCookie   = 'vmv_PredL_' . $timeStamp;
  $pageId          = $option['previewIdPage'];
  $viewEachLoad    = esc_html( stripslashes( $option['viewEachLoad'] ) );

  global $post;
  $demoView = $post->ID == $pageId;

  if ( ( ( ! isset( $_COOKIE[ $currentCookie ] ) && $pluginActivated && $isNotCrawler ) || $demoView || $viewEachLoad === 'true' ) ) {
    put_main_code_to_template();
  }
}